Various helper modules
======================

Has these modules:

* decor - helper decorators.
* log - helpers with stdout, stderr management.

Source code in:

* `github <https://github.com/focusate/footil/>`_.
* `pypi <https://pypi.org/project/footil/>`_.

Contributors
============

* Silvija Butko (Focusate)
* Andrius Laukavičius (Focusate)
